Account class

Constructors

Account({String? sId, Institution? institution, String? name, String? accountNumber, num? balance, String? currency, String? userReference, String? bvn})
Account.fromJson(Map<String, dynamic>? json)

Properties

accountNumber String?
getter/setter pair
balance num?
getter/setter pair
bvn String?
getter/setter pair
currency String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
institution Institution?
getter/setter pair
name String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sId String?
getter/setter pair
userReference String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited