Ui class mixin

Constructors

Ui()

Properties

blackText Color
getter/setter pair
grey0 Color
getter/setter pair
grey1 Color
getter/setter pair
grey2 Color
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
orange Color
getter/setter pair
primaryBlue Color
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

amount(dynamic text, double size, dynamic color, dynamic weight) Widget
backNav(dynamic context) Widget
backNavIcon(BuildContext context) Widget
buttomTag() Widget
button(dynamic text, dynamic width) Widget
buttonColored(dynamic text, dynamic width, dynamic color) Widget
cancelIcon(BuildContext context) Widget
divider() Widget
headerText(dynamic text) Widget
height(dynamic context) double
message(BuildContext context, String message) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
outlineButton(dynamic text, dynamic width) Widget
popScreen(BuildContext context) → dynamic
progress(BuildContext context) → dynamic
text(dynamic text, double size, dynamic color, dynamic weight) Widget
textJustified(dynamic text, double size, dynamic color, dynamic weight) Widget
toString() String
A string representation of this object.
inherited
width(dynamic context) double

Operators

operator ==(Object other) bool
The equality operator.
inherited