Zeeh class
Constructors
- Zeeh.start({required BuildContext context, required String publicKey, required String orgId, required String userReference})
Properties
- context ↔ BuildContext
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- orgId → String
-
organisation ID
final
- publicKey → String
-
public key
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userReference → String
-
userReference
final
Methods
-
initialize(
) → Future< LinkingResponse> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited