AppUrl class
Constructors
- AppUrl()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- access → const String
- bank → const String
- baseUrl → const String
- carbon → const String
- carbonOTP → const String
- fcmb → const String
- fidelity → const String
- firstBank → const String
- firstBankOTP → const String
- keystone → const String
- keystoneOTP → const String
- kuda → const String
- kudaOTP → const String
- opay → const String
- opayBVN → const String
- opayOTP → const String
- piggyvest → const String
- piggyvestOTP → const String
- pocketApp → const String
- pocketAppOTP → const String
- stanbic → const String
- sterling → const String
- uba → const String
- unity → const String
- wema → const String
- zenith → const String